gitrepo

package
v0.0.0-...-e51afbe Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 11, 2024 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsGitRepository

func IsGitRepository(repoPath string) error

IsGitRepository checks if the current directory is a git repository.

Types

type DiffOutput

type DiffOutput struct {
	DiffString string
	FileDiffs  []diff.FilePatch
}

DiffOutput stores information about the git diff.

func GetDiff

func GetDiff(repoPath string) (*DiffOutput, error)

GetDiff returns the diff between the current commit and its parent.

Jump to