Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsGitRepository ¶
IsGitRepository checks if the current directory is a git repository.
Types ¶
type DiffOutput ¶
DiffOutput stores information about the git diff.
func GetDiff ¶
func GetDiff(repoPath string) (*DiffOutput, error)
GetDiff returns the diff between the current commit and its parent.
Click to show internal directories.
Click to hide internal directories.